@@ -69,7 +69,7 @@ public:
 	void reshape();
 	
 public slots:
-	void setImage(QPixmap img,int pageNr);
+	void setImage(const QPixmap &img, int pageNr);
 	
 protected:
 	virtual void paintEvent(QPaintEvent *event);
@@ -269,14 +269,6 @@ private:
 	QShortcut *shortcutLeft;
 	QShortcut *shortcutDown;
 	QShortcut *shortcutRight;
-	QShortcut *shortcutPageUp1;
-	QShortcut *shortcutPageUp2;
-	QShortcut *shortcutPageUp3;
-	QShortcut *shortcutPageUp4;
-	QShortcut *shortcutPageDown1;
-	QShortcut *shortcutPageDown2;
-	QShortcut *shortcutPageDown3;
-	QShortcut *shortcutPageDown4;
 
 	QPixmap image;
 	QRect	imageRect;
@@ -392,7 +384,7 @@ protected:
 
 public slots:
 	void reloadSettings();
-	void reload(bool fillCache=true);
+	void loadCurrentFile(bool fillCache=true);
 	void fillRenderCache(int pg=-1);
 	void sideBySide();
     void doFindDialog(const QString command="");
@@ -448,7 +440,7 @@ private slots:
     void shrink();
 signals:
 	void documentClosed();
-	void reloaded();
+	void documentLoaded();
 	void syncSource(const QString& sourceFile, int line, bool activate, const QString& guessedWord); //view -> source
 	void syncView(const QString& pdfFile, const QFileInfo& masterFile, int page); //view -> other view
 	void focusEditor();
@@ -502,6 +494,9 @@ public:
 private:
 	QMenu *menuEdit_2;
 
+	QAction *actionPage_Up;
+	QAction *actionPage_Down;
+
 	QButtonGroup	*toolButtonGroup;
 	QToolButton *comboZoom;
 	QLineEdit *leCurrentPage;
