@@ -27,6 +27,7 @@ const QString ShortcutDelegate::deleteRowButton="<internal: delete row>";
 static const QString nameSeparator = "separator";
 
 ShortcutComboBox::ShortcutComboBox(QWidget *parent):QComboBox(parent){
+    setObjectName("ShortcutComboBox");
 	setMaxVisibleItems(15);
 	addItem(tr("<default>"));
 	addItem(tr("<none>"));
@@ -56,7 +57,7 @@ ShortcutComboBox::ShortcutComboBox(QWidget *parent):QComboBox(parent){
 }
 
 void ShortcutComboBox::keyPressEvent(QKeyEvent *e){
-	if ( (e->modifiers()!=0 && e->text() != "+" && e->key() != Qt::Key_Alt && e->key() != Qt::Key_Shift && e->key() != Qt::Key_Control && e->key() != Qt::Key_AltGr && e->key() != Qt::Key_Meta && e->key() != 0 && e->key() != Qt::Key_Super_L && e->key() != Qt::Key_Super_R)
+    if ( (e->modifiers()!=0 && e->text() != "+" && e->key() != Qt::Key_Alt && e->key() != Qt::Key_Shift && e->key() != Qt::Key_Control && e->key() != Qt::Key_AltGr && e->key() != Qt::Key_Meta && e->key() != 0 && e->key() != Qt::Key_Super_L && e->key() != Qt::Key_Super_R)
         || (e->key() >= Qt::Key_F1 &&  e->key() <= Qt::Key_F35)
         || (e->key() == Qt::Key_Home)
         || (e->key() == Qt::Key_End)
@@ -396,6 +397,7 @@ ConfigDialog::ConfigDialog(QWidget* parent): QDialog(parent), checkboxInternalPD
 	fmConfig->addCategory(tr("Line highlighting"))     <<"line:error" <<"line:warning" <<"line:badbox" <<"line:bookmark" <<"line:bookmark0" <<"line:bookmark1" <<"line:bookmark2" <<"line:bookmark3" <<"line:bookmark4" <<"line:bookmark5" <<"line:bookmark6"  <<"line:bookmark7" <<"line:bookmark8"<<"line:bookmark9"<<"current";
 	fmConfig->addCategory(tr("Search")) <<"search"<<"replacement"<<"selection";
 	fmConfig->addCategory(tr("Diff")) <<"diffDelete"<<"diffAdd"<<"diffReplace";
+    fmConfig->addCategory(tr("Preview")) <<"previewSelection";
 	fmConfig->addCategory(tr("DTX files")) << "dtx:guard" << "dtx:macro" << "dtx:verbatim" << "dtx:specialchar" << "dtx:commands";
 	fmConfig->addCategory(tr("Sweave / Pweave")) << "sweave-delimiter" << "sweave-block" << "pweave-delimiter" << "pweave-block";
 	fmConfig->addCategory(tr("Lua")) << "lua:keyword" << "lua:comment";
@@ -475,6 +477,15 @@ ConfigDialog::ConfigDialog(QWidget* parent): QDialog(parent), checkboxInternalPD
 	ui.checkBoxVisualColumnMode->setChecked(false);
 	ui.checkBoxVisualColumnMode->setEnabled(false);
 #endif
+
+    // poppler preview
+#ifdef NO_POPPLER_PREVIEW
+    int l=ui.comboBoxDvi2PngMode->count();
+    ui.comboBoxDvi2PngMode->removeItem(l-1);
+    l=ui.comboBoxPreviewMode->count();
+    ui.comboBoxPreviewMode->removeItem(l-1);
+    // maybe add some possibility to disable some preview modes in poppler mode
+#endif
 }
 
 ConfigDialog::~ConfigDialog() {
@@ -954,4 +965,3 @@ bool ConfigDialog::askRiddle(){
 	*/
 }
 
-
