@@ -62,6 +62,8 @@ public:
 	QPalette systemPalette; 
 	QString interfaceStyle;
 	QString interfaceFontFamily;
+	int guiToolbarIconSize;
+	int guiSecondaryToolbarIconSize;
 	bool useTexmakerPalette;
 	int interfaceFontSize;
 	bool newLeftPanelLayout;
@@ -120,7 +122,7 @@ public:
 	double logViewWarnIfFileSizeLargerMB;
 
 	//preview
-	enum PreviewMode {PM_TOOLTIP_AS_FALLBACK=0, PM_PANEL,PM_TOOLTIP,PM_BOTH,PM_INLINE};
+    enum PreviewMode {PM_TOOLTIP_AS_FALLBACK=0, PM_PANEL,PM_TOOLTIP,PM_BOTH,PM_INLINE,PM_EMBEDDED};
 	enum AutoPreviewMode {AP_NEVER = 0, AP_PREVIOUSLY = 1};
 	PreviewMode previewMode; 
 	AutoPreviewMode autoPreview;
@@ -178,6 +180,10 @@ public:
 	QList<QMenu*> managedMenus;
 	QHash<QString,QKeySequence> managedMenuShortcuts;
 	QList<QPair<QString,QString> > managedMenuNewShortcuts;
+#if (QT_VERSION > 0x050000) && (defined(Q_OS_MAC))
+    //workaround that osx/qt does not support alt+key/esc as shortcuts
+    QMap<QKeySequence,QAction*> specialShortcuts;
+#endif
 		
 	QMenu* newManagedMenu(const QString &id,const QString &text);
 	QMenu* newManagedMenu(QMenu* menu, const QString &id,const QString &text);
