@@ -42,7 +42,12 @@ void IconDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
 	// do layout
 	value = model->data(index, Qt::DecorationRole);
 	QPixmap pixmap = decoration(opt, value);
-    const int overScale= isRetinaMac() ? 2 : 1;
+#if QT_VERSION >= 0x050000
+    int overScale= painter->device()->devicePixelRatio();
+#else
+    int overScale= isRetinaMac() ? 2 : 1;
+#endif
+
     QSize pixmapSize= pixmap.size()/overScale;
     QRect pixmapRect(QPoint(0,0),pixmapSize);
     //QRect pixmapRect=pixmap.rect();
@@ -289,8 +294,8 @@ QPixmap IconDelegate::decoration(const QStyleOptionViewItem &option, const QVari
 */
 
 QPixmap *IconDelegate::selected(const QPixmap &pixmap, const QPalette &palette, bool enabled) const {
-	QString key;
-    key.sprintf("%d-%d", pixmap.cacheKey(), enabled);
+    QString key=QString("%1-%2").arg(pixmap.cacheKey()).arg(enabled);
+    //key.sprintf("%d-%d", pixmap.cacheKey(), boolKey);
 	QPixmap *pm = QPixmapCache::find(key);
 	if (!pm) {
 		QImage img = pixmap.toImage().convertToFormat(QImage::Format_ARGB32_Premultiplied);
