@@ -37,7 +37,7 @@ QValidator::State PlacementValidator::validate(QString &input, int &pos) const {
 
 QStringList InsertGraphics::widthUnits = QStringList() << "\\linewidth" << "cm" << "mm" << "";
 QStringList InsertGraphics::heightUnits = QStringList() << "\\textheight" << "cm" << "mm" << "";
-QStringList InsertGraphics::m_imageFormats = QStringList() << "eps" << "jpg" << "png" << "pdf";
+QStringList InsertGraphics::m_imageFormats = QStringList() << "eps" << "jpg" << "jpeg" << "png" << "pdf";
 
 InsertGraphics::InsertGraphics(QWidget *parent, InsertGraphicsConfig *conf)
 		: QDialog(parent) {
@@ -87,7 +87,6 @@ InsertGraphics::InsertGraphics(QWidget *parent, InsertGraphicsConfig *conf)
 	ui.cbPlaceForce->setToolTip(tooltip);
 
 	includeOptionChanged();
-	filter = "Images (*.eps *.jpg *.png *.pdf)";
 
 	ui.cbWidthUnit->insertItems(0, widthUnits);
 	ui.cbHeightUnit->insertItems(0, heightUnits);
@@ -338,38 +337,18 @@ QString InsertGraphics::getCode() const {
 	QString fname=conf.file;
 	QFileInfo info(fname);
 	if(info.isAbsolute()){
-		QString imgpath=info.absolutePath();
 		QFileInfo texFileInfo = masterTexFile.exists() ? masterTexFile : texFile;
-		QString texpath=texFileInfo.absolutePath();
-		if(imgpath.startsWith(texpath) && !texpath.isEmpty()){
-			// make relative with "./"
-			imgpath=imgpath.mid(texpath.length()+((texpath.endsWith('/') || texpath.endsWith(QDir::separator()))?0:1));
-			if(!imgpath.isEmpty())
-				imgpath="./"+imgpath+"/";
-			fname=imgpath+info.completeBaseName();
-		} else {
-			// try make relative with "../"
-			QDir dir = QDir(texFileInfo.absoluteDir());
-			if (dir.cdUp()) {
-				QString path = dir.absolutePath();
-				if(imgpath.startsWith(path)){
-					fname="../";
-					if (imgpath.length()>path.length())
-						fname+=imgpath.mid(path.length()+((path.endsWith('/') || path.endsWith(QDir::separator())) ?0:1))+"/";
-					fname+=info.completeBaseName();
-				}
-			}
-		}
+		fname = getRelativeBaseNameToPath(info.filePath(), texFileInfo.absolutePath());
+		if (fname.startsWith("./")) fname.remove(0, 2);
 	}
-	info.setFile(fname);
-	fname=info.path();
-	if(!fname.isEmpty()) fname+="/"+info.completeBaseName();
 #ifdef Q_OS_WIN
 	//restore native separators if original filename contains native separators
 	if(conf.file.contains(QDir::separator())){
 		fname=QDir::toNativeSeparators(fname);
 	}
 #endif
+	if (fname.contains(' ') && !(fname.length()>1 && fname[0]=='"' && fname[fname.length()-1]=='"'))
+		fname = '"'+fname+'"';
 	insert.append("{"+fname+"}\n");
 	if(conf.useFigure){
 		if(conf.captionBelow) insert.append(getCaptionLabelString(conf));
@@ -392,7 +371,7 @@ void InsertGraphics::chooseFile() {
 	foreach (const QString &fmt, m_imageFormats) {
 		exts.append("*."+fmt);
 	};
-	QString filter = "Images (" + exts.join(" ")+")";
+    QString filter = tr("Images") + " (" + exts.join(" ")+")";
 	fn =QFileDialog::getOpenFileName(this,tr("Select a File","Wizard"),texFile.absolutePath(),filter);
 	if (!fn.isEmpty()) {
 		ui.leFile->setText(fn);
