@@ -1,5 +1,6 @@
 #include "latexlogwidget.h"
 #include "smallUsefulFunctions.h"
+#include "configmanager.h"
 
 LatexLogWidget::LatexLogWidget(QWidget *parent) :
 	QWidget(parent), logModel(0), displayPartsActions(0), logpresent(false)
@@ -87,9 +88,9 @@ bool LatexLogWidget::loadLogFile(const QString &logname, const QString & compile
 
 	QFile f(logname);
 	if (f.open(QIODevice::ReadOnly)) {
-
-		if (f.size() > 2*1024*1024 &&
-			!txsConfirmWarning(tr("The logfile is very large (> %1 MB) are you sure you want to load it?").arg(f.size() / 1024 / 1024)))
+		double fileSizeLimitMB = ConfigManagerInterface::getInstance()->getOption("LogView/WarnIfFileSizeLargerMB").toDouble();
+		if (f.size() > fileSizeLimitMB*1024*1024 &&
+			!txsConfirmWarning(tr("The logfile is very large (%1 MB) are you sure you want to load it?").arg(double(f.size()) / 1024 / 1024, 0, 'f', 2)))
 			return false;
 
 		//QByteArray fullLog = simplifyLineConserving(f.readAll());
@@ -109,9 +110,20 @@ bool LatexLogWidget::loadLogFile(const QString &logname, const QString & compile
 		logModel->parseLogDocument(log->document(), compiledFileName);
 
 		logpresent=true;
-		//update table size
+
+		// workaround to https://sourceforge.net/p/texstudio/feature-requests/622/
+		// There seems to be a bug in Qt (4.8.4) that resizeRowsToContents() does not work correctly if
+		// horizontalHeader()->setStretchLastSection(true) and the tableView has not yet been shown
+		// when iterating through the columns to determine the maximal height, everything is fine
+		// until the last column. There the calculated height is too large.
+		// As a workaround we will temporarily deactivate column stretching.
+		// Note: To reproduce, you can call the viewer via The ViewLog button. When showing the viewer
+		// by clicking the ViewTab, the widget is shown before loading (so there the bug did not appear.)
+		bool visible = errorTable->isVisible();
+		if (!visible) errorTable->horizontalHeader()->setStretchLastSection(false);
 		errorTable->resizeColumnsToContents();
 		errorTable->resizeRowsToContents();
+		if (!visible) errorTable->horizontalHeader()->setStretchLastSection(true);
 
 		selectLogEntry(0);
 		emit logLoaded();
