@@ -12,10 +12,10 @@
  ***************************************************************************/
 
 #include "mostQtHeaders.h"
- 
+
 #include "texmaker.h"
 #include "smallUsefulFunctions.h"
-
+#include "debughelper.h"
 
 #if QT_VERSION >= 0x040400
 #include <qtsingleapplication.h>
@@ -24,9 +24,9 @@
 #endif
 
 #include <QSplashScreen>
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN32
 #include "windows.h"
-typedef BOOL (*AllowSetForegroundWindowFunc)(DWORD);
+typedef BOOL (WINAPI * AllowSetForegroundWindowFunc)(DWORD);
 #endif
 
 
@@ -154,7 +154,7 @@ int main(int argc, char ** argv) {
 #else
 		if (instance.isRunning()) {
 #endif
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN32
 			AllowSetForegroundWindowFunc asfw = (AllowSetForegroundWindowFunc)GetProcAddress(GetModuleHandleA("user32.dll"),"AllowSetForegroundWindow");
 			if (asfw) asfw(/*ASFW_ANY*/(DWORD)(-1));
 #endif
@@ -178,5 +178,12 @@ int main(int argc, char ** argv) {
 					 a.mw,   SLOT(onOtherInstanceMessage(const QString &)));
 #endif
 
-	return a.exec();
+	try {
+		return a.exec();
+	} catch (...) {
+#ifndef NO_CRASH_HANDLER
+		catchUnhandledException();
+#endif
+		throw;
+	}
 }
