@@ -40,8 +40,8 @@ void MakeTemplateDialog::tryAccept()
 	fn.append("."+ext);
 	m_suggestedFile = QFileInfo(QDir(m_templateDir), fn);
 	if (m_suggestedFile.exists()) {
-		bool abort = txsConfirmWarning(tr("A template with the given name already exists.\nDo you want to overwrite it?")+"\n"+m_suggestedFile.canonicalFilePath());
-		if (abort)
+		bool overwrite = txsConfirmWarning(tr("A template with the given name already exists.\nDo you want to overwrite it?")+"\n"+m_suggestedFile.canonicalFilePath());
+		if (!overwrite)
 			return;
 	}
 	accept();
