@@ -126,7 +126,7 @@ public:
 };
 
 ManhattanStyle::ManhattanStyle(const QString &baseStyleName)
-#if QT_VERSION<0x050000
+#if QT_VERSION<0x040600
     : QWindowsStyle(), d(new ManhattanStylePrivate(baseStyleName))
 #else
     : QProxyStyle(), d(new ManhattanStylePrivate(baseStyleName))
@@ -536,7 +536,7 @@ void ManhattanStyle::drawPrimitive(PrimitiveElement element, const QStyleOption
             QLinearGradient grad(option->rect.topLeft(), QPoint(rect.center().x(), rect.bottom()));
             QColor startColor = StyleHelper::shadowColor().darker(164);
             QColor endColor = StyleHelper::baseColor().darker(130);
-            grad.setColorAt(0, endColor);
+            grad.setColorAt(0, startColor);
             grad.setColorAt(1, endColor);
             painter->fillRect(option->rect, grad);
             painter->setPen(QColor(255, 255, 255, 60));
@@ -576,8 +576,8 @@ void ManhattanStyle::drawPrimitive(PrimitiveElement element, const QStyleOption
             bool horizontal = option->state & State_Horizontal;
             painter->save();
             QPainterPath path;
-            int x = option->rect.x() + horizontal ? 2 : 6;
-            int y = option->rect.y() + horizontal ? 6 : 2;
+            int x = option->rect.x() + (horizontal ? 2 : 6 );
+            int y = option->rect.y() + (horizontal ? 6 : 2 );
             static const int RectHeight = 2;
             if (horizontal) {
                 while (y < option->rect.height() - RectHeight - 6) {
@@ -944,7 +944,7 @@ void ManhattanStyle::drawComplexControl(ComplexControl control, const QStyleOpti
                     if (bflags & State_Sunken || bflags & State_On)
                         drawCornerImage(d->buttonImage_pressed, painter, option->rect, 2, 2, 2, 2);
                     else if (bflags & State_Enabled) {
-#ifndef Q_WS_MAC
+#ifndef Q_OS_MAC
                         if (bflags & State_MouseOver) {
                             drawCornerImage(d->buttonImage, painter, option->rect, 2, 2, 2, 2);
                             QColor shade(255, 255, 255, 50);
@@ -996,7 +996,7 @@ void ManhattanStyle::drawComplexControl(ComplexControl control, const QStyleOpti
                         QColor shade(0, 0, 0, 50);
                         painter->fillRect(tool.rect.adjusted(0, -1, 1, 1), shade);
                     }
-#ifndef Q_WS_MAC
+#ifndef Q_OS_MAC
                     else if (mflags & (State_MouseOver)) {
                         QColor shade(255, 255, 255, 50);
                         painter->fillRect(tool.rect.adjusted(0, -1, 1, 1), shade);
