@@ -18,7 +18,7 @@
 const int kMaxPageZoom=1000000;
 const qreal kMaxDpiForFullPage= isRetinaMac() ? 1000.0 : 500.0;
 
-PDFQueue::PDFQueue(QObject *parent): QObject(parent){
+PDFQueue::PDFQueue(QObject *parent): QObject(parent), stopped(true), num_renderQueues(1){
 #if QT_VERSION < 0x040400
     m_ref.init(1);
 #else
@@ -49,7 +49,7 @@ void CachePixmap::setRes(qreal res, int x, int y){
 }
 
 PDFRenderManager::PDFRenderManager(QObject *parent,int limitQueues) :
-       QObject(parent), cachedNumPages(0)
+	   QObject(parent), cachedNumPages(0), loadStrategy(HybridLoad)
 {
 	queueAdministration=new PDFQueue();
     if(limitQueues>0){
@@ -87,6 +87,10 @@ void PDFRenderManager::setCacheSize(int megabyte) {
 	renderedPages.setMaxCost(megabyte);
 }
 
+void PDFRenderManager::setLoadStrategy(int strategy) {
+	loadStrategy = strategy;
+}
+
 QSharedPointer<Poppler::Document> PDFRenderManager::loadDocument(const QString &fileName, Error &error, bool foreceLoad){
 	renderedPages.clear();
 	QFile f(fileName);
@@ -95,15 +99,33 @@ QSharedPointer<Poppler::Document> PDFRenderManager::loadDocument(const QString &
 		return QSharedPointer<Poppler::Document>();
 	}
 	
-	queueAdministration->documentData = f.readAll();
-	if (!queueAdministration->documentData.mid(qMax(0, queueAdministration->documentData.size() - 1024)).trimmed().endsWith("%%EOF") &&
-	    !foreceLoad) {
-		error = FileIncomplete;
+	Poppler::Document *docPtr;
+
+	try {
+		if (loadStrategy==DirectLoad) {
+			docPtr = Poppler::Document::load(fileName);
+		} else {
+			// load data into buffer and check for completeness
+			queueAdministration->documentData = f.readAll();
+			if (!queueAdministration->documentData.mid(qMax(0, queueAdministration->documentData.size() - 1024)).trimmed().endsWith("%%EOF") &&
+					!foreceLoad) {
+				error = FileIncomplete;
+				return QSharedPointer<Poppler::Document>();
+			}
+			// create document
+			if (loadStrategy == BufferedLoad || (loadStrategy == HybridLoad && queueAdministration->documentData.size() < 50000000))
+				docPtr = Poppler::Document::loadFromData(queueAdministration->documentData);
+			else
+				docPtr = Poppler::Document::load(fileName);
+		}
+	} catch (std::bad_alloc) {
+		error = PopplerErrorBadAlloc;
+		return QSharedPointer<Poppler::Document>();
+	} catch (...) {
+		error = PopplerErrorException;
 		return QSharedPointer<Poppler::Document>();
 	}
 
-	Poppler::Document *docPtr;
-	docPtr = Poppler::Document::loadFromData(queueAdministration->documentData);
 	if (!docPtr) {
 		error = PopplerError;
 		return QSharedPointer<Poppler::Document>();
@@ -122,12 +144,38 @@ QSharedPointer<Poppler::Document> PDFRenderManager::loadDocument(const QString &
 	docPtr->setRenderHint(Poppler::Document::Antialiasing);
 	docPtr->setRenderHint(Poppler::Document::TextAntialiasing);
 
+	document = QSharedPointer<Poppler::Document>(docPtr);
 
 	for(int i=0;i<queueAdministration->num_renderQueues;i++){
-		// poppler is not thread-safe, so each render engine needs a separate Poppler::Document
-		Poppler::Document *doc=Poppler::Document::loadFromData(queueAdministration->documentData);
-		QSharedPointer<Poppler::Document> spDoc(doc);
-		queueAdministration->renderQueues[i]->setDocument(spDoc);
+
+#ifdef HAS_POPPLER_24
+		// poppler claims to be thread safe ...
+		queueAdministration->renderQueues[i]->setDocument(document);
+#else
+		Poppler::Document *doc;
+		try {
+			if (loadStrategy == BufferedLoad || (loadStrategy == HybridLoad && queueAdministration->documentData.size() < 50000000)) {
+				// poppler is not thread-safe, so each render engine needs a separate Poppler::Document
+				doc=Poppler::Document::loadFromData(queueAdministration->documentData);
+			} else {
+				// Workaround: loadFromData crashes if called with large data for the second time (i==1).
+				// See also bug report https://sourceforge.net/p/texstudio/bugs/710/?page=2
+				// I used a 200 MB file in the tests. Also 150 MB and 66 MB was reported to crash.
+				// Likely an internal Poppler bug. Exact conditions need to be tested so we can file a bug report.
+				doc=Poppler::Document::load(fileName);
+			}
+			QSharedPointer<Poppler::Document> spDoc(doc);
+			queueAdministration->renderQueues[i]->setDocument(spDoc);
+		} catch (std::bad_alloc) {
+			Q_ASSERT(false);
+			error = PopplerErrorBadAlloc;
+			return QSharedPointer<Poppler::Document>();
+		} catch (...) {
+			Q_ASSERT(false);
+			error = PopplerErrorException;
+			return QSharedPointer<Poppler::Document>();
+		}
+
 		if (!doc) {
 			Q_ASSERT(false);
 			error = FileIncomplete;
@@ -136,13 +184,17 @@ QSharedPointer<Poppler::Document> PDFRenderManager::loadDocument(const QString &
 		doc->setRenderBackend(Poppler::Document::SplashBackend);
 		doc->setRenderHint(Poppler::Document::Antialiasing);
 		doc->setRenderHint(Poppler::Document::TextAntialiasing);
+#endif
+
 		if(!queueAdministration->renderQueues[i]->isRunning())
 			queueAdministration->renderQueues[i]->start();
 	}
 	mFillCacheMode=true;
 
+	queueAdministration->documentData.clear(); // remove file, as poppler made a copy of its own
+
 	error = NoError;
-	document = QSharedPointer<Poppler::Document>(docPtr);
+
 	return document;
 }
 
