@@ -108,7 +108,9 @@ class QCE_EXPORT QEditor : public QAbstractScrollArea
 			AutoInsertLRM		= 0x08000000,
 			BidiVisualColumnMode= 0x10000000,
 
-			SilentReloadOnExternalChanges = 0x20000000,
+			ShowPlaceholders = 0x20000000,
+			OverwriteOpeningBracketFollowedByPlaceholder = 0x40000000,
+			OverwriteClosingBracketFollowingPlaceholder = 0x80000000,
 
 			Accessible		= 0xfffff000
 		};
@@ -276,12 +278,28 @@ class QCE_EXPORT QEditor : public QAbstractScrollArea
 		
 		int wrapWidth() const;
 
-		bool displayModifyTime();
+		bool displayModifyTime() const;
 		void setDisplayModifyTime(bool flag) {mDisplayModifyTime=flag;}
+
+		bool silentReloadOnExternalChanges() const {return mSilentReloadOnExternalChanges;}
+		void setSilentReloadOnExternalChanges(bool flag) {mSilentReloadOnExternalChanges=flag;}
+
 		inline int horizontalOffset() const
-		{ return horizontalScrollBar()->isVisible() ? horizontalScrollBar()->value() : 0; }
+        {
+#if QT_VERSION >= 0x050000 && defined Q_OS_MAC
+            return horizontalScrollBar()->value();
+#else
+            return horizontalScrollBar()->isVisible() ? horizontalScrollBar()->value() : 0;
+#endif
+        }
 		inline int verticalOffset() const
-		{ return verticalScrollBar()->isVisible() ? verticalScrollBar()->value() * m_doc->getLineSpacing() : 0; }
+        {
+#if QT_VERSION >= 0x050000 && defined Q_OS_MAC
+            return verticalScrollBar()->value() * m_doc->getLineSpacing();  // does this work always ?
+#else
+            return verticalScrollBar()->isVisible() ? verticalScrollBar()->value() * m_doc->getLineSpacing() : 0;
+#endif
+        }
 		
 		inline QPoint mapToContents(const QPoint &point) const
 		{
@@ -371,6 +389,8 @@ class QCE_EXPORT QEditor : public QAbstractScrollArea
 		void setLineWrapping(bool on);
 		void setHardLineWrapping(bool on);
 		void setSoftLimitedLineWrapping(bool on);
+		void setWrapAfterNumChars(int numChars);
+protected:
 		void setWrapLineWidth(int l);
 public:		
 		virtual void save();
@@ -392,6 +412,7 @@ public slots:
 		void removeAction(QAction *a, const QString& menu, const QString& toolbar = QString());
 		
 		void load(const QString& file, QTextCodec* codec/* = QTextCodec::codecForLocale()*/);
+		void reload();
 		
 		void setText(const QString& s, bool allowUndo = true);
 		
@@ -456,6 +477,7 @@ public slots:
 		void fileInConflict();
 		void fileAutoReloading(QString fname);
 		void needUpdatedCompleter();
+        void requestClose();
 
 		void cursorHovered();
 
@@ -625,6 +647,7 @@ public slots:
 		QBasicTimer m_blink, m_click, m_drag;
 
 		bool mDisplayModifyTime;
+		bool mSilentReloadOnExternalChanges;
 		
 		static QReliableFileWatch* watcher();
 		
@@ -650,6 +673,7 @@ public slots:
 		int m_cursorSurroundingLines;
 		
 		int m_LineWidth;
+		int m_wrapAfterNumChars;
 
 #if QT_VERSION >= 0x040600
 		QPropertyAnimation *m_scrollAnimation;
