@@ -364,16 +364,20 @@ void QuickDocumentDialog::geometryValuesChanged(){
 	//draw paper
 	qreal resolution = qMin((ui.geometryPreviewLabel->width()-5)/physicalPaperWidth, (ui.geometryPreviewLabel->height()-5)/physicalPaperHeight);
 	QPixmap preview((int)(physicalPaperWidth*resolution+6), (int)(physicalPaperHeight*resolution+5));
+	preview.fill(QColor(0,0,0));
 
 	QPainter painter(&preview);
+    QBrush brush(QColor(255,255,255));
+    brush.setStyle(Qt::SolidPattern);
+    painter.setBrush(brush);
+    painter.drawRect(2,2,qRound(physicalPaperWidth*resolution), qRound(physicalPaperHeight*resolution));
 
-	painter.setTransform(QTransform().scale(resolution, resolution)*QTransform().translate(2,2));
+    painter.setTransform(QTransform().scale(resolution, resolution)*QTransform().translate(2,2));
 
-	preview.fill(QColor(0,0,0));
-	painter.setBrush(QBrush(QColor(255,255,255),Qt::SolidPattern));
-	painter.drawRect(QRectF(0,0,physicalPaperWidth, physicalPaperHeight));
+    QPen pen(QColor(128,128,128));
+    pen.setWidth(0);
+    painter.setPen(pen);
 
-	painter.setPen(QColor(128,128,128));
 	painter.drawLine(QPointF(marginLeft, 0), QPointF(marginLeft, physicalPaperHeight));
 	painter.drawLine(QPointF(0, marginTop), QPointF(physicalPaperWidth, marginTop));
 	painter.drawLine(QPointF(physicalPaperWidth - marginRight, 0), QPointF(physicalPaperWidth - marginRight, physicalPaperHeight));
