@@ -11,6 +11,7 @@
 
 #include "spellerutility.h"
 #include "smallUsefulFunctions.h"
+#include "JlCompress.h"
 
 int SpellerUtility::spellcheckErrorFormat = -1;
 
@@ -184,34 +185,49 @@ SpellerManager::~SpellerManager() {
 	}
 }
 
+bool SpellerManager::isOxtDictionary(const QString &fileName) {
+	QFileInfo fi(fileName);
+
+	if (!(QStringList() << "oxt" << "zip").contains(fi.suffix())) return false;
+	QStringList files = JlCompress::getFileList(fileName);
+	QString affFile;
+	QString dicFile;
+	foreach (const QString &f, files) {
+		if (f.endsWith(".aff")) {
+			affFile = f;
+		}
+		if (f.endsWith(".dic")) {
+			dicFile = f;
+		}
+	}
+	if (affFile.length() <= 4 || dicFile.length() <= 4) return false;
+	if (affFile.left(affFile.length()-4) != affFile.left(affFile.length()-4)) return false; // different names
+	return true;
+}
+
+bool SpellerManager::importDictionary(const QString &fileName, const QString &targetDir) {
+	QFileInfo fi(fileName);
+	if (!(QStringList() << "oxt" << "zip").contains(fi.suffix())) return false;
+	QStringList extractedFiles = JlCompress::extractDir(fileName, QDir(targetDir).filePath(fi.fileName()));
+	return !extractedFiles.isEmpty();
+}
+
 void SpellerManager::setIgnoreFilePrefix(const QString &prefix) {
 	ignoreFilePrefix = prefix;
 }
 
-void SpellerManager::setDictPath(const QString &dictPath) {
-	if (dictPath == m_dictPath) return;
-	m_dictPath = dictPath;
+void SpellerManager::setDictPaths(const QStringList &dictPaths) {
+	if (dictPaths == m_dictPaths) return;
+	m_dictPaths = dictPaths;
 
 	QList<SpellerUtility *> oldDicts = dicts.values();
 
 	dicts.clear();
 	dictFiles.clear();
-	QDir dir(dictPath);
 	QMap<QString, QString> usedFiles;
-	foreach (QFileInfo fi, dir.entryInfoList(QStringList() << "*.dic", QDir::Files, QDir::Name)) {
-		QString realDictFile;
-		if (fi.isSymLink()) realDictFile = QFileInfo(fi.symLinkTarget()).canonicalFilePath();
-		else realDictFile = fi.canonicalFilePath();
-		
-		if ( usedFiles.value(fi.baseName().replace("_", "-"), "") == realDictFile )
-			continue;
-		else 
-			usedFiles.insert(fi.baseName().replace("_", "-"), realDictFile);
-			
-		
-		dictFiles.insert(fi.baseName(), fi.canonicalFilePath());
+	foreach (const QString &path, dictPaths) {
+		scanForDictionaries(path);
 	}
-	
 
 	// delete after new dict files are identified so a user can reload the new dict in response to a aboutToDelete signal
 	foreach (SpellerUtility *su, oldDicts) {
@@ -221,23 +237,29 @@ void SpellerManager::setDictPath(const QString &dictPath) {
 	emit dictPathChanged();
 }
 
+void SpellerManager::scanForDictionaries(const QString & path) {
+	if (path.isEmpty()) return;
+	QDirIterator iterator(path, QDirIterator::Subdirectories);
+	while (iterator.hasNext()) {
+		iterator.next();
+		if (!iterator.fileInfo().isDir()) {
+			if (iterator.fileName().endsWith(".dic")) {
+				QFileInfo fi(iterator.fileInfo());
+				QString realDictFile = (fi.isSymLink()) ? QFileInfo(fi.symLinkTarget()).canonicalFilePath() : fi.canonicalFilePath();
+				if (dictFiles.contains(fi.baseName()))
+					continue;
+				dictFiles.insert(fi.baseName(), realDictFile);
+			}
+		}
+	}
+}
+
 QStringList SpellerManager::availableDicts() {
 	if (dictFiles.keys().isEmpty())
 		return QStringList() << emptySpeller->name();
 	return QStringList(dictFiles.keys());
 }
 
-QStringList SpellerManager::dictNamesForDir(const QString &dir) {
-	QStringList dictNames;
-
-	foreach (QFileInfo fi, QDir(dir).entryInfoList(QStringList() << "*.dic", QDir::Files, QDir::Name)) {
-		dictNames << fi.baseName();
-	}
-	if (dictNames.isEmpty())
-		return QStringList() << "<none>";
-	return dictNames;
-}
-
 bool SpellerManager::hasSpeller(const QString &name) {
 	if (name==emptySpeller->name()) return true;
 	return dictFiles.contains(name);
