@@ -6,8 +6,12 @@
 #include "configmanager.h"
 
 QStringList LatexTables::tabularNames = QStringList() << "tabular" << "array" << "longtable" << "supertabular" << "tabu" << "longtabu";
-QStringList LatexTables::tabularNamesWithOneOption = QStringList() << "tabular*" << "tabularx";
-QStringList LatexTables::mathTables = QStringList() << "align" << "align*" << "array" << "matrix" << "bmatrix" << "pmatrix" << "vmatrix" << "Vmatrix" << "split" << "multline" << "multline*" << "gather" << "gather*" << "flalign" << "flalign*" << "alignat" << "alignat*" << "cases";
+QStringList LatexTables::tabularNamesWithOneOption = QStringList() << "tabular*" << "tabularx" << "tabulary";
+QStringList LatexTables::mathTables = QStringList() << "align" << "align*" << "array" << "matrix" << "matrix*" << "bmatrix" << "bmatrix*"
+													<< "Bmatrix" << "Bmatrix*" << "pmatrix" << "pmatrix*" << "vmatrix" << "vmatrix*"
+													<< "Vmatrix" << "Vmatrix*" << "split" << "multline" << "multline*"
+													<< "gather" << "gather*" << "flalign" << "flalign*" << "alignat" << "alignat*"
+													<< "cases" << "aligned" << "gathered" << "alignedat";
 
 void LatexTables::addRow(QDocumentCursor &c,const int numberOfColumns ){
 	QDocumentCursor cur(c);
