@@ -16,15 +16,16 @@ private slots:
 		QTest::addColumn<QString>("package");
 		QTest::addColumn<QString>("fileWithoutPath");
 
-        QTest::newRow("fancyhdr") << "fancyhdr" << "fancyhdr.dvi;fancyhdr.pdf";
-		QTest::newRow("xcolor") << "xcolor" << "xcolor.pdf";
-        QTest::newRow("graphicx") << "graphicx" << "graphicx.pdf;grfguide.pdf";
-        QTest::newRow("fancyref") << "fancyref" << "freftest.dvi;fancyref.pdf";
+		QTest::newRow("fancyhdr") << "fancyhdr" << "fancyhdr.dvi;fancyhdr.pdf";
+		QTest::newRow("ifthen") << "ifthen" << "ifthen.pdf";
+		QTest::newRow("graphicx") << "graphicx" << "graphicx.pdf;grfguide.pdf";
+		QTest::newRow("fancyref") << "fancyref" << "freftest.dvi;fancyref.pdf";
 	}
 
 	void packageDocFile() {
 		QFETCH(QString, package);
 		QFETCH(QString, fileWithoutPath);
+		if (!globalExecuteAllTests) { qDebug("skip"); return; }
         QStringList lst=fileWithoutPath.split(";");
 		QString file = Help::packageDocFile(package);
         bool found=false;
