@@ -327,10 +327,10 @@ private slots:
 		QTest::addColumn<int>("out");
 
 		QTest::newRow("command") << "\\begin{test}" << 3 << 1;
-		QTest::newRow("content") << "\\begin{test}" << 8 << 2;
-                QTest::newRow("option") << "\\begin[abc]{test}" << 8 << 3;
-		QTest::newRow("content with option") << "\\begin[abc]{test}" << 13 << 2;
-                QTest::newRow("content with option2") << "\\begin[\\abc]{test}" << 14 << 2;
+        QTest::newRow("content") << "\\begin{test}" << 8 << 3;
+                QTest::newRow("option") << "\\begin[abc]{test}" << 8 << 2;
+        QTest::newRow("content with option") << "\\begin[abc]{test}" << 13 << 3;
+                QTest::newRow("content with option2") << "\\begin[\\abc]{test}" << 14 << 3;
 		QTest::newRow("command with option") << "\\begin[abc]{test}" << 3 << 1;
 		QTest::newRow("nothing") << "\\begin{test}" << 0 << 0;
 	}
@@ -348,7 +348,7 @@ private slots:
 		QTest::addColumn<QString>("command");
 		QTest::addColumn<QString>("value");
 
-		QTest::newRow("command") << "\\begin{test}" << 3 << (int)LatexParser::Command << "\\begin" <<"test";
+        QTest::newRow("command") << "\\begin{test}" << 3 << (int)LatexParser::Command << "\\begin" <<"test";
 		QTest::newRow("content") << "\\begin{test}" << 8 << (int)LatexParser::Environment << "\\begin" <<"test";
 		QTest::newRow("ref") << "\\ref{test}" << 8 << (int)LatexParser::Reference << "\\ref" <<"test";
 		QTest::newRow("label") << "\\label{test}" << 8 << (int)LatexParser::Label << "\\label" <<"test";
@@ -376,27 +376,32 @@ private slots:
 		QTest::addColumn<int>("column");
 		QTest::addColumn<QStringList>("expectedValues");
 		QTest::addColumn<QList<int> >("expectedStarts");
+		QTest::addColumn<bool>("expectedComplete");
 
-		QTest::newRow("noOption") << "\\begin nothing" << 0 << (QStringList()) << (QList<int>());
-		QTest::newRow("singleOption") << "\\begin{test}" << 0 << (QStringList() << "{test}") << (QList<int>() << 6);
-		QTest::newRow("singleOptionSpace") << "\\begin {test}" << 0 << (QStringList() << "{test}") << (QList<int>() << 7);
-		QTest::newRow("multiOption") << "\\begin{test 1}{test 2}" << 0 << (QStringList() << "{test 1}" << "{test 2}") << (QList<int>() << 6 << 14);
-		QTest::newRow("multiOption2") << "\\begin[test 1]{test 2}" << 0 << (QStringList() << "[test 1]" << "{test 2}") << (QList<int>() << 6 << 14);
-		QTest::newRow("multiOption3") << "\\begin{test 1}[test 2]{test 3}" << 0 << (QStringList() << "{test 1}" << "[test 2]" << "{test 3}") << (QList<int>() << 6 << 14 << 22);
-		QTest::newRow("cmdStart") << "\\section{\\LaTeX rules}" << 0 << (QStringList() << "{\\LaTeX rules}") << (QList<int>() << 8);
-		QTest::newRow("cmdMid") << "\\section{a \\textit{nested} command}" << 0 << (QStringList() << "{a \\textit{nested} command}") << (QList<int>() << 8);
+		QTest::newRow("noOption") << "\\begin nothing" << 0 << (QStringList()) << (QList<int>()) << true;
+		QTest::newRow("singleOption") << "\\begin{test}" << 0 << (QStringList() << "{test}") << (QList<int>() << 6) << true;
+		QTest::newRow("singleOptionSpace") << "\\begin {test}" << 0 << (QStringList() << "{test}") << (QList<int>() << 7) << true;
+		QTest::newRow("multiOption") << "\\begin{test 1}{test 2}" << 0 << (QStringList() << "{test 1}" << "{test 2}") << (QList<int>() << 6 << 14) << true;
+		QTest::newRow("multiOption2") << "\\begin[test 1]{test 2}" << 0 << (QStringList() << "[test 1]" << "{test 2}") << (QList<int>() << 6 << 14) << true;
+		QTest::newRow("multiOption3") << "\\begin{test 1}[test 2]{test 3}" << 0 << (QStringList() << "{test 1}" << "[test 2]" << "{test 3}") << (QList<int>() << 6 << 14 << 22) << true;
+		QTest::newRow("cmdStart") << "\\section{\\LaTeX rules}" << 0 << (QStringList() << "{\\LaTeX rules}") << (QList<int>() << 8) << true;
+		QTest::newRow("cmdMid") << "\\section{a \\textit{nested} command}" << 0 << (QStringList() << "{a \\textit{nested} command}") << (QList<int>() << 8) << true;
+		QTest::newRow("incomplete") << "\\section{text" << 0 << (QStringList()) << (QList<int>()) << false;
+		QTest::newRow("incomplete2") << "\\section{text}{more" << 0 << (QStringList() << "{text}") << (QList<int>() << 8) << false;
 	}
 	void test_resolveCommandOptions(){
 		QFETCH(QString, line);
 		QFETCH(int, column);
 		QFETCH(QStringList, expectedValues);
 		QFETCH(QList<int>, expectedStarts);
+		QFETCH(bool, expectedComplete);
 		QStringList values;
 		QList<int> starts;
-		LatexParser::resolveCommandOptions(line, column, values, &starts);
+		bool complete = LatexParser::resolveCommandOptions(line, column, values, &starts);
 		QEQUAL(values.length(), starts.length());
 		QEQUAL(values.join("|"), expectedValues.join("|"));
 		QVERIFY(starts == expectedStarts);
+		QEQUAL(complete, expectedComplete);
 	}
 	void test_lineStart_data(){
 		QTest::addColumn<QString>("text");
