@@ -18,16 +18,19 @@
 #include "syntaxcheck_t.h"
 #include "updatechecker_t.h"
 #include "help_t.h"
+#include "latexoutputfilter_t.h"
 #include <QtTest/QtTest>
 
 const QRegExp TestToken::simpleTextRegExp ("[A-Z'a-z0-9]+.?");
 const QRegExp TestToken::commandRegExp ("\\\\([A-Za-z]+|.)");
 const QRegExp TestToken::ignoredTextRegExp ("[$\t *!{}.\\][]+");
-const QRegExp TestToken::specialCharTextRegExp ("[A-Z'\"\\\\\\{\\}a-z0-9]+");
+const QRegExp TestToken::specialCharTextRegExp ("[A-Z'\"\\\\\\{\\}a-z0-9ö]+");
 const QRegExp TestToken::punctationRegExp("[!():\"?,.;-]");
 
 int totalTestTime;
 char* tempResult;
+bool globalExecuteAllTests;
+
 
 QString TestManager::performTest(QObject* obj){
 	char* argv[3];
@@ -54,13 +57,15 @@ QString TestManager::execute(TestLevel level, LatexEditorView* edView, QCodeEdit
 	tf.close();
 	tempResult = tfn.data();
 	
+	globalExecuteAllTests = level == TL_ALL;
 	
 	//codeedit, editor are passed as extra parameters and not extracted from edView, so we don't have
 	//to include latexeditorview.h here
 	totalTestTime = 0;
 	QString tr;
 	QList<QObject*> tests=QList<QObject*>()
-        << new SmallUsefulFunctionsTest()
+		<< new SmallUsefulFunctionsTest()
+		<< new LatexOutputFilterTest()
 		<< new BuildManagerTest(buildManager)
 		<< new CodeSnippetTest(editor)
 		<< new QDocumentLineTest()
