@@ -13,12 +13,12 @@
 #define LIST_RESERVE(list, count)
 #endif
 
-extern const char* TEXSTUDIO_SVN_VERSION;
-
-int getSimplifiedSVNVersion(QString svnVersion = TEXSTUDIO_SVN_VERSION);
+extern const char* TEXSTUDIO_HG_REVISION;
 
 bool getDiskFreeSpace(const QString &path, quint64 &freeBytes);
 
+QChar getPathListSeparator();
+
 QString getUserName();
 
 QString getUserDocumentFolder();
@@ -46,6 +46,7 @@ QString ensureTrailingDirSeparator(const QString& dirPath);
 QString replaceFileExtension(const QString& filename, const QString& newExtension, bool appendIfNoExt=false);
 QString getRelativeBaseNameToPath(const QString & file, QString basepath, bool baseFile=false, bool keepSuffix=false);
 QString getPathfromFilename(const QString &compFile);
+QString findAbsoluteFilePath(const QString & relName, const QString &extension, const QStringList &searchPaths, const QString& fallbackPath);
 
 //returns kde version 0,3,4
 int x11desktop_env();
@@ -57,6 +58,7 @@ bool hasAtLeastQt(int major, int minor);
 
 bool connectUnique(const QObject * sender, const char * signal, const QObject * receiver, const char * method);
 
+QString execCommand(const QString & cmd);
 
 class ThreadBreaker : public QThread
 {
